"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateCompLibs = exports.generateCode = exports.deserialize = exports.serialize = void 0;
const generate_1 = require("./generate");
const material_1 = require("./material");
const common_1 = require("../types/common");
const template_1 = __importDefault(require("../template"));
const path_1 = __importDefault(require("path"));
const types_1 = require("../../types");
const lodash_1 = require("lodash");
var weapps_core_1 = require("../../weapps-core");
Object.defineProperty(exports, "serialize", { enumerable: true, get: function () { return weapps_core_1.serialize; } });
Object.defineProperty(exports, "deserialize", { enumerable: true, get: function () { return weapps_core_1.deserialize; } });
async function generateCode(props) {
    const { cals, mainAppData, subAppDataList = [], dependencies, appKey = 'test', i18nConfig = {
        enabled: false,
        i18nData: {},
    }, extraData = {
        isComposite: false,
        compProps: {},
    }, basename = '/', isSandbox = false, buildTypeList = [common_1.BuildType.WEB], ignoreInstall = false, deployMode = types_1.DEPLOY_MODE.PREVIEW, runtime = types_1.RUNTIME.NONE, } = props;
    // 处理应用数据
    const fileCodeMap = {};
    const appBuildDir = '/';
    const excludeRegex = null;
    const includeRegex = /^\/src\/(utils|app)/;
    // const includeRegex = /^\/src\/(utils|app|store)/; // 现阶段不通过store来生成
    copyFiles({
        appBuildDir,
        excludeRegex,
        includeRegex,
        fileCodeMap,
    });
    // i8n数据
    // fileCodeMap[path.join(appBuildDir, 'src/i18n/index.js')] = {
    //   code: `export default ${JSON.stringify(i18nConfig.i18nData, null, 2)}`,
    // };
    // 素材库
    if (!isSandbox) {
        await (0, material_1.runHandleMaterial)(appBuildDir, dependencies, i18nConfig, fileCodeMap, isSandbox);
    }
    // 生成核心文件
    await (0, generate_1.runGenerateCore)({
        appBuildDir,
        appData: mainAppData,
        cals,
        subAppDataList,
        dependencies,
        appKey,
        buildTypeList,
        basename,
        extraData,
        i18nConfig,
        fileCodeMap,
        isSandbox,
        ignoreInstall,
        deployMode,
        runtime,
    });
    return fileCodeMap;
}
exports.generateCode = generateCode;
async function generateCompLibs(compLibs) {
    const fileCodeMap = {};
    const dependencies = compLibs;
    const isSandbox = true;
    const i18nConfig = {};
    const appBuildDir = '/';
    await (0, material_1.runHandleMaterial)(appBuildDir, dependencies, i18nConfig, fileCodeMap, isSandbox);
    const includeRegex = /^\/src\/(utils|handlers)/;
    copyFiles({
        appBuildDir,
        excludeRegex: null,
        includeRegex,
        fileCodeMap,
    });
    // 注入鉴权函数代码
    fileCodeMap['/src/utils/common.js'] = {
        code: (0, lodash_1.template)(template_1.default['/src/utils/common.js'].code, {
            interpolate: /<%=([\s\S]+?)%>/g,
        })({
            isSandbox,
            isAdminPortal: false,
        }),
    };
    return fileCodeMap;
}
exports.generateCompLibs = generateCompLibs;
function copyFiles({ appBuildDir, excludeRegex, includeRegex, fileCodeMap }) {
    Object.keys(template_1.default).map((filePath) => {
        if (includeRegex) {
            const isInclude = includeRegex.test(filePath);
            if (isInclude) {
                const isExclude = excludeRegex === null || excludeRegex === void 0 ? void 0 : excludeRegex.test(filePath);
                if (isExclude) {
                    return;
                }
                const dstFile = path_1.default.join(appBuildDir, filePath);
                fileCodeMap[dstFile] = {
                    code: template_1.default[filePath].code,
                };
            }
        }
    });
}
